@@ -135,6 +135,28 @@ class Shell:
         """
         os.system("clear")
 
+    @staticmethod
+    def reboot():
+        """
+        Reboot the system
+        """
+        os.system("reboot")
+
+    @staticmethod
+    def getcwd():
+        """
+        Get the Current Working Directory
+        """
+        return os.getcwd()
+
+    def chdir(self, directory):
+        """
+        Change directory
+        """
+        if directory[0] != "/" and directory[0] != ".":
+            directory = self.getcwd() + "/" + directory
+        return os.chdir(directory)
+
     @staticmethod
     def is_root():
         """
@@ -158,6 +180,7 @@ class Shell:
         """
         if append:
             mode = "a"
+            content = "\n" + content
         else:
             mode = "w"
         service_file = open(path, mode)
